"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtPositioning import *
import enum


class QGeoCoordinate(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeocoordinate.html

    **Detailed Description**

    A QGeoCoordinate is defined by latitude, longitude, and optionally,
    altitude.

    Use **type** () to determine whether a coordinate is a 2D coordinate (has
    latitude and longitude only) or 3D coordinate (has latitude, longitude and
    altitude). Use **distanceTo** () and **azimuthTo** () to calculate the
    distance and bearing between coordinates.

    The coordinate values should be specified using the WGS84 datum. For more
    information on geographical terms see this article on **coordinates**  and
    another on **geodetic systems**  including WGS84.

    Azimuth in this context is equivalent to a compass bearing based on true
    north.

    This class is a **Q_GADGET**  since Qt 5.5. It can be **directly used from
    C++ and QML** .
    """

    class CoordinateFormat(enum.Enum):
        Degrees: QGeoCoordinate = ...
        DegreesWithHemisphere: QGeoCoordinate = ...
        DegreesMinutes: QGeoCoordinate = ...
        DegreesMinutesWithHemisphere: QGeoCoordinate = ...
        DegreesMinutesSeconds: QGeoCoordinate = ...
        DegreesMinutesSecondsWithHemisphere: QGeoCoordinate = ...

    class CoordinateType(enum.Enum):
        InvalidCoordinate: QGeoCoordinate = ...
        Coordinate2D: QGeoCoordinate = ...
        Coordinate3D: QGeoCoordinate = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#QGeoCoordinate

        **QGeoCoordinate::QGeoCoordinate()**

        Constructs a coordinate. The coordinate will be invalid until
        **setLatitude** () and **setLongitude** () have been called.
        """
        ...

    @typing.overload
    def __init__(self, latitude: float, longitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#QGeoCoordinate-1

        **QGeoCoordinate::QGeoCoordinate(double latitude , double longitude )**

        Constructs a coordinate with the given **latitude** and **longitude**.

        If the latitude is not between -90 to 90 inclusive, or the longitude is
        not between -180 to 180 inclusive, none of the values are set and the
        **type** () will be **QGeoCoordinate::InvalidCoordinate** .

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, latitude: float, longitude: float, altitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#QGeoCoordinate-2

        **QGeoCoordinate::QGeoCoordinate(double latitude , double longitude ,
        double altitude )**

        Constructs a coordinate with the given **latitude** , **longitude** and
        **altitude**.

        If the latitude is not between -90 to 90 inclusive, or the longitude is
        not between -180 to 180 inclusive, none of the values are set and the
        **type** () will be **QGeoCoordinate::InvalidCoordinate** .

        Note that **altitude** specifies the meters above sea level.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoCoordinate") -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#QGeoCoordinate-3

        **QGeoCoordinate::QGeoCoordinate(const QGeoCoordinate & other )**

        Constructs a coordinate from the contents of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QGeoCoordinate") -> None:
        ...

    def toString(self, format: "QGeoCoordinate.CoordinateFormat" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#toString

        **[invokable] QString
        QGeoCoordinate::toString(QGeoCoordinate::CoordinateFormat format =
        DegreesMinutesSecondsWithHemisphere) const**

        Returns this coordinate as a string in the specified **format**.

        For example, if this coordinate has a latitude of -27.46758, a longitude
        of 153.027892 and an altitude of 28.1, these are the strings returned
        depending on **format** :

        **format** valueReturned string
        **Degrees** -27.46758°, 153.02789°,
        28.1m
        **DegreesWithHemisphere** 27.46758° S, 153.02789° E, 28.1m
        **DegreesMinutes** -27° 28.054', 153° 1.673', 28.1m
        **DegreesMinutesWithHemisphere** 27° 28.054 S', 153° 1.673' E, 28.1m
        **DegreesMinutesSeconds** -27° 28' 3.2", 153° 1' 40.4", 28.1m
        **DegreesMinutesSecondsWithHemisphere** 27° 28' 3.2" S, 153° 1' 40.4" E,
        28.1m

        The altitude field is omitted if no altitude is set.

        If the coordinate is invalid, an empty string is returned.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def atDistanceAndAzimuth(
        self, distance: float, azimuth: float, distanceUp: float = ...
    ) -> "QGeoCoordinate":
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#atDistanceAndAzimuth

        **[invokable] QGeoCoordinate QGeoCoordinate::atDistanceAndAzimuth(qreal
        distance , qreal azimuth , qreal distanceUp = 0.0) const**

        Returns the coordinate that is reached by traveling **distance** meters
        from the current coordinate at **azimuth** (or bearing) along a great-
        circle. There is an assumption that the Earth is spherical for the
        purpose of this calculation.

        The altitude will have **distanceUp** added to it.

        Returns an invalid coordinate if this coordinate is invalid.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def azimuthTo(self, other: "QGeoCoordinate") -> float:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#azimuthTo

        **[invokable] qreal QGeoCoordinate::azimuthTo(const QGeoCoordinate &
        other ) const**

        Returns the azimuth (or bearing) in degrees from this coordinate to the
        coordinate specified by **other**. Altitude is not used in the
        calculation.

        The bearing returned is the bearing from the origin to **other** along
        the great-circle between the two coordinates. There is an assumption
        that the Earth is spherical for the purpose of this calculation.

        Returns 0 if the type of this coordinate or the type of **other** is
        **QGeoCoordinate::InvalidCoordinate** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def distanceTo(self, other: "QGeoCoordinate") -> float:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#distanceTo

        **[invokable] qreal QGeoCoordinate::distanceTo(const QGeoCoordinate &
        other ) const**

        Returns the distance (in meters) from this coordinate to the coordinate
        specified by **other**. Altitude is not used in the calculation.

        This calculation returns the great-circle distance between the two
        coordinates, with an assumption that the Earth is spherical for the
        purpose of this calculation.

        Returns 0 if the type of this coordinate or the type of **other** is
        **QGeoCoordinate::InvalidCoordinate** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def altitude(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#altitude

        **double QGeoCoordinate::altitude() const**

        Returns the altitude (meters above sea level).

        The return value is undefined if the altitude has not been set.

        **Note:** Getter function for property **altitude** .

        **See also** **setAltitude** () and **type** ().
        """
        ...

    def setAltitude(self, altitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#setAltitude

        **void QGeoCoordinate::setAltitude(double altitude )**

        Sets the altitude (meters above sea level) to **altitude**.

        **Note:** Setter function for property **altitude** .

        **See also** **altitude** ().
        """
        ...

    def longitude(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#longitude

        **double QGeoCoordinate::longitude() const**

        Returns the longitude, in decimal degrees. The return value is undefined
        if the longitude has not been set.

        A positive longitude indicates the Eastern Hemisphere, and a negative
        longitude indicates the Western Hemisphere.

        **Note:** Getter function for property **longitude** .

        **See also** **setLongitude** () and **type** ().
        """
        ...

    def setLongitude(self, longitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#setLongitude

        **void QGeoCoordinate::setLongitude(double longitude )**

        Sets the longitude (in decimal degrees) to **longitude**. The value
        should be in the WGS84 datum.

        To be valid, the longitude must be between -180 to 180 inclusive.

        **Note:** Setter function for property **longitude** .

        **See also** **longitude** ().
        """
        ...

    def latitude(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#latitude

        **double QGeoCoordinate::latitude() const**

        Returns the latitude, in decimal degrees. The return value is undefined
        if the latitude has not been set.

        A positive latitude indicates the Northern Hemisphere, and a negative
        latitude indicates the Southern Hemisphere.

        **Note:** Getter function for property **latitude** .

        **See also** **setLatitude** () and **type** ().
        """
        ...

    def setLatitude(self, latitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#setLatitude

        **void QGeoCoordinate::setLatitude(double latitude )**

        Sets the latitude (in decimal degrees) to **latitude**. The value should
        be in the WGS84 datum.

        To be valid, the latitude must be between -90 to 90 inclusive.

        **Note:** Setter function for property **latitude** .

        **See also** **latitude** ().
        """
        ...

    def type(self) -> "QGeoCoordinate.CoordinateType":
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#type

        **QGeoCoordinate::CoordinateType QGeoCoordinate::type() const**

        Returns the type of this coordinate.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeocoordinate.html#isValid

        **bool QGeoCoordinate::isValid() const**

        Returns `true` if the **longitude**  and **latitude**  are valid.

        **Note:** Getter function for property **isValid** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtNetwork import *
import enum


class QHostAddress(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhostaddress.html

    **Detailed Description**

    This class holds an IPv4 or IPv6 address in a platform- and protocol-
    independent manner.

    QHostAddress is normally used with the **QTcpSocket** , **QTcpServer** , and
    **QUdpSocket**  to connect to a host or to set up a server.

    A host address is set with **setAddress** (), and retrieved with
    **toIPv4Address** (), **toIPv6Address** (), or **toString** (). You can
    check the type with **protocol** ().

    **Note:** Please note that QHostAddress does not do DNS lookups.
    **QHostInfo**  is needed for that.

    The class also supports common predefined addresses: **Null** ,
    **LocalHost** , **LocalHostIPv6** , **Broadcast** , and **Any** .

    **See also** **QHostInfo** , **QTcpSocket** , **QTcpServer** , and
    **QUdpSocket** .
    """

    class ConversionModeFlag(enum.Flag):
        ConvertV4MappedToIPv4: QHostAddress = ...
        ConvertV4CompatToIPv4: QHostAddress = ...
        ConvertUnspecifiedAddress: QHostAddress = ...
        ConvertLocalHost: QHostAddress = ...
        TolerantConversion: QHostAddress = ...
        StrictConversion: QHostAddress = ...

    class SpecialAddress(enum.Enum):
        Null: QHostAddress = ...
        Broadcast: QHostAddress = ...
        LocalHost: QHostAddress = ...
        LocalHostIPv6: QHostAddress = ...
        AnyIPv4: QHostAddress = ...
        AnyIPv6: QHostAddress = ...
        Any: QHostAddress = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress

        **QHostAddress::QHostAddress()**

        Constructs a null host address object, i.e. an address which is not
        valid for any host or interface.

        **See also** **clear** ().
        """
        ...

    @typing.overload
    def __init__(self, address: "QHostAddress.SpecialAddress") -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress-1

        **QHostAddress::QHostAddress(quint32 ip4Addr )**

        Constructs a host address object with the IPv4 address **ip4Addr**.
        """
        ...

    @typing.overload
    def __init__(self, ip4Addr: int) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress-2

        **[since 5.5] QHostAddress::QHostAddress(const quint8 * ip6Addr )**

        Constructs a host address object with the IPv6 address **ip6Addr**.

        **ip6Addr** must be a 16-byte array in network byte order (big endian).

        This function was introduced in Qt 5.5.
        """
        ...

    @typing.overload
    def __init__(self, address: str) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress-3

        **QHostAddress::QHostAddress(const Q_IPV6ADDR & ip6Addr )**

        Constructs a host address object with the IPv6 address **ip6Addr**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        ip6Addr: typing.Tuple[
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress-4

        **QHostAddress::QHostAddress(const sockaddr * sockaddr )**

        Constructs an IPv4 or IPv6 address using the address specified by the
        native structure **sockaddr**.

        **See also** **setAddress** ().
        """
        ...

    @typing.overload
    def __init__(
        self, copy: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#QHostAddress-5

        **QHostAddress::QHostAddress(const QString & address )**

        Constructs an IPv4 or IPv6 address based on the string **address**
        (e.g., "127.0.0.1").

        **See also** **setAddress** ().
        """
        ...

    def isBroadcast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isBroadcast

        **[since 5.11] bool QHostAddress::isBroadcast() const**

        Returns `true` if the address is the IPv4 broadcast address, `false`
        otherwise. The IPv4 broadcast address is 255.255.255.255.

        Note that this function does not return true for an IPv4 network's local
        broadcast address. For that, please use **QNetworkInterface**  to obtain
        the broadcast addresses of the local machine.

        This function was introduced in Qt 5.11.

        **See also** **isLoopback** (), **isGlobal** (), **isMulticast** (),
        **isLinkLocal** (), and **isUniqueLocalUnicast** ().
        """
        ...

    def isUniqueLocalUnicast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isUniqueLocalUnicast

        **[since 5.11] bool QHostAddress::isUniqueLocalUnicast() const**

        Returns `true` if the address is an IPv6 unique local unicast address,
        `false` otherwise.

        An IPv6 unique local unicast address is one in the network fc00::/7. See
        the **IANA IPv6 Address Space**  registry for more information.

        Note that Unique local unicast addresses count as global addresses too.
        RFC 4193 says that, in practice, "applications may treat these addresses
        like global scoped addresses." Only routers need care about the
        distinction.

        This function was introduced in Qt 5.11.

        **See also** **isLoopback** (), **isGlobal** (), **isMulticast** (),
        **isLinkLocal** (), and isUniqueLocalUnicast().
        """
        ...

    def isSiteLocal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isSiteLocal

        **[since 5.11] bool QHostAddress::isSiteLocal() const**

        Returns `true` if the address is an IPv6 site-local address, `false`
        otherwise.

        An IPv6 site-local address is one in the network fec0::/10. See the
        **IANA IPv6 Address Space**  registry for more information.

        IPv6 site-local addresses are deprecated and should not be depended upon
        in new applications. New applications should not depend on this function
        and should consider site-local addresses the same as global (which is
        why **isGlobal** () also returns true). Site-local addresses were
        replaced by Unique Local Addresses (ULA).

        This function was introduced in Qt 5.11.

        **See also** **isLoopback** (), **isGlobal** (), **isMulticast** (),
        **isLinkLocal** (), and **isUniqueLocalUnicast** ().
        """
        ...

    def isLinkLocal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isLinkLocal

        **[since 5.11] bool QHostAddress::isLinkLocal() const**

        Returns `true` if the address is an IPv4 or IPv6 link-local address,
        `false` otherwise.

        An IPv4 link-local address is an address in the network 169.254.0.0/16.
        An IPv6 link-local address is one in the network fe80::/10. See the
        **IANA IPv6 Address Space**  registry for more information.

        This function was introduced in Qt 5.11.

        **See also** **isLoopback** (), **isGlobal** (), **isMulticast** (),
        **isSiteLocal** (), and **isUniqueLocalUnicast** ().
        """
        ...

    def isGlobal(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isGlobal

        **[since 5.11] bool QHostAddress::isGlobal() const**

        Returns `true` if the address is an IPv4 or IPv6 global address, `false`
        otherwise. A global address is an address that is not reserved for
        special purposes (like loopback or multicast) or future purposes.

        Note that IPv6 unique local unicast addresses are considered global
        addresses (see **isUniqueLocalUnicast** ()), as are IPv4 addresses
        reserved for local networks by **RFC 1918** .

        Also note that IPv6 site-local addresses are deprecated and should be
        considered as global in new applications. This function returns true for
        site-local addresses too.

        This function was introduced in Qt 5.11.

        **See also** **isLoopback** (), **isSiteLocal** (), and
        **isUniqueLocalUnicast** ().
        """
        ...

    def isEqual(
        self,
        address: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"],
        mode: "QHostAddress.ConversionModeFlag" = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isEqual

        **[since 5.8] bool QHostAddress::isEqual(const QHostAddress & other ,
        QHostAddress::ConversionMode mode = TolerantConversion) const**

        Returns `true` if this host address is the same as the **other** address
        given; otherwise returns `false`.

        The parameter **mode** controls which conversions are preformed between
        addresses of differing protocols. If no **mode** is given,
        `TolerantConversion` is performed by default.

        This function was introduced in Qt 5.8.

        **See also** **ConversionMode**  and **operator==** ().
        """
        ...

    def isMulticast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isMulticast

        **[since 5.6] bool QHostAddress::isMulticast() const**

        Returns `true` if the address is an IPv4 or IPv6 multicast address,
        `false` otherwise.

        This function was introduced in Qt 5.6.

        **See also** **isLoopback** (), **isGlobal** (), **isLinkLocal** (),
        **isSiteLocal** (), and **isUniqueLocalUnicast** ().
        """
        ...

    def swap(self, other: "QHostAddress") -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#swap

        **[since 5.6] void QHostAddress::swap(QHostAddress & other )**

        Swaps this host address with **other**. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.6.
        """
        ...

    @staticmethod
    def parseSubnet(subnet: str) -> typing.Tuple["QHostAddress", int]:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#parseSubnet

        **[static] QPair<QHostAddress, int> QHostAddress::parseSubnet(const
        QString & subnet )**

        Parses the IP and subnet information contained in **subnet** and returns
        the network prefix for that network and its prefix length.

        The IP address and the netmask must be separated by a slash (/).

        This function supports arguments in the form:

        * 123.123.123.123/n where n is any value between 0 and 32
          *
        123.123.123.123/255.255.255.255
          * <ipv6-address>/n where n is any
        value between 0 and 128

        For IP version 4, this function accepts as well missing trailing
        components (i.e., less than 4 octets, like "192.168.1"), followed or not
        by a dot. If the netmask is also missing in that case, it is set to the
        number of octets actually passed (in the example above, it would be 24,
        for 3 octets).

        **See also** **isInSubnet** ().
        """
        ...

    def isLoopback(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isLoopback

        **[since 5.0] bool QHostAddress::isLoopback() const**

        returns `true` if the address is the IPv6 loopback address, or any of
        the IPv4 loopback addresses.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def isInSubnet(
        self,
        subnet: typing.Union["QHostAddress", "QHostAddress.SpecialAddress"],
        netmask: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isInSubnet

        **bool QHostAddress::isInSubnet(const QHostAddress & subnet , int
        netmask ) const**

        Returns `true` if this IP is in the subnet described by the network
        prefix **subnet** and netmask **netmask**.

        An IP is considered to belong to a subnet if it is contained between the
        lowest and the highest address in that subnet. In the case of IP version
        4, the lowest address is the network address, while the highest address
        is the broadcast address.

        The **subnet** argument does not have to be the actual network address
        (the lowest address in the subnet). It can be any valid IP belonging to
        that subnet. In particular, if it is equal to the IP address held by
        this object, this function will always return true (provided the netmask
        is a valid value).

        **See also** **parseSubnet** ().
        """
        ...

    @typing.overload
    def isInSubnet(
        self,
        subnet: typing.Tuple[
            typing.Union["QHostAddress", "QHostAddress.SpecialAddress"], int
        ],
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isInSubnet-1

        **bool QHostAddress::isInSubnet(const QPair<QHostAddress, int> & subnet
        ) const**

        This is an overloaded function.

        Returns `true` if this IP is in the subnet described by **subnet**. The
        **QHostAddress**  member of **subnet** contains the network prefix and
        the int (second) member contains the netmask (prefix length).
        """
        ...

    def __hash__(self) -> int:
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#clear

        **void QHostAddress::clear()**

        Sets the host address to null and sets the protocol to
        **QAbstractSocket::UnknownNetworkLayerProtocol** .

        **See also** **QHostAddress::Null** .
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#isNull

        **bool QHostAddress::isNull() const**

        Returns `true` if this host address is not valid for any host or
        interface.

        The default constructor creates a null address.

        **See also** **QHostAddress::Null** .
        """
        ...

    def setScopeId(self, id: str) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#setScopeId

        **void QHostAddress::setScopeId(const QString & id )**

        Sets the IPv6 scope ID of the address to **id**. If the address protocol
        is not IPv6, this function does nothing. The scope ID may be set as an
        interface name (such as "eth0" or "en1") or as an integer representing
        the interface index. If **id** is an interface name, **QtNetwork**  will
        convert to an interface index using
        **QNetworkInterface::interfaceIndexFromName** () before calling the
        operating system networking functions.

        **See also** **scopeId** (), **QNetworkInterface** , and
        **QNetworkInterface::interfaceFromName** .
        """
        ...

    def scopeId(self) -> str:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#scopeId

        **QString QHostAddress::scopeId() const**

        Returns the scope ID of an IPv6 address. For IPv4 addresses, or if the
        address does not contain a scope ID, an empty **QString**  is returned.

        The IPv6 scope ID specifies the scope of **reachability** for non-global
        IPv6 addresses, limiting the area in which the address can be used. All
        IPv6 addresses are associated with such a reachability scope. The scope
        ID is used to disambiguate addresses that are not guaranteed to be
        globally unique.

        IPv6 specifies the following four levels of reachability:

        * Node-local: Addresses that are only used for communicating with
        services on the same interface (e.g., the loopback interface "::1").
          *
        Link-local: Addresses that are local to the network interface ( **link**
        ). There is always one link-local address for each IPv6 interface on
        your host. Link-local addresses ("fe80...") are generated from the MAC
        address of the local network adaptor, and are not guaranteed to be
        unique.
          * Global: For globally routable addresses, such as public
        servers on the Internet.

        When using a link-local or site-local address for IPv6 connections, you
        must specify the scope ID. The scope ID for a link-local address is
        usually the same as the interface name (e.g., "eth0", "en1") or number
        (e.g., "1", "2").

        **See also** **setScopeId** (), **QNetworkInterface** , and
        **QNetworkInterface::interfaceFromName** .
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#toString

        **QString QHostAddress::toString() const**

        Returns the address as a string.

        For example, if the address is the IPv4 address 127.0.0.1, the returned
        string is "127.0.0.1". For IPv6 the string format will follow the
        RFC5952 recommendation. For **QHostAddress::Any** , its IPv4 address
        will be returned ("0.0.0.0")

        **See also** **toIPv4Address** ().
        """
        ...

    def toIPv6Address(
        self,
    ) -> typing.Tuple[
        int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int
    ]:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#toIPv6Address

        **Q_IPV6ADDR QHostAddress::toIPv6Address() const**

        Returns the IPv6 address as a Q_IPV6ADDR structure. The structure
        consists of 16 unsigned characters.

        Q_IPV6ADDR addr = hostAddr.toIPv6Address();
            // addr contains 16
        unsigned characters

            for (int i = 0; i < 16; ++i) {
                //
        process addr[i]
            }

        This value is valid if the **protocol** () is **IPv6Protocol** . If the
        protocol is **IPv4Protocol** , then the address is returned an an IPv4
        mapped IPv6 address. (RFC4291)

        **See also** **toString** ().
        """
        ...

    def toIPv4Address(self) -> typing.Tuple[int, bool]:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#toIPv4Address

        **quint32 QHostAddress::toIPv4Address(bool * ok = nullptr) const**

        Returns the IPv4 address as a number.

        For example, if the address is 127.0.0.1, the returned value is
        2130706433 (i.e. 0x7f000001).

        This value is valid if the **protocol** () is **IPv4Protocol** , or if
        the protocol is **IPv6Protocol** , and the IPv6 address is an IPv4
        mapped address (RFC4291). In those cases, **ok** will be set to true.
        Otherwise, it will be set to false.

        **See also** **toString** ().
        """
        ...

    def protocol(self) -> QAbstractSocket.NetworkLayerProtocol:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#protocol

        **int QHostAddress::protocol() const**

        Returns the network layer protocol of the host address.
        """
        ...

    @typing.overload
    def setAddress(self, address: "QHostAddress.SpecialAddress") -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#setAddress

        **void QHostAddress::setAddress(quint32 ip4Addr )**

        Set the IPv4 address specified by **ip4Addr**.
        """
        ...

    @typing.overload
    def setAddress(self, ip4Addr: int) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#setAddress-1

        **[since 5.5] void QHostAddress::setAddress(const quint8 * ip6Addr )**

        This is an overloaded function.

        Set the IPv6 address specified by **ip6Addr**.

        **ip6Addr** must be an array of 16 bytes in network byte order (high-
        order byte first).

        This function was introduced in Qt 5.5.
        """
        ...

    @typing.overload
    def setAddress(self, address: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#setAddress-2

        **void QHostAddress::setAddress(const Q_IPV6ADDR & ip6Addr )**

        This is an overloaded function.

        Set the IPv6 address specified by **ip6Addr**.
        """
        ...

    @typing.overload
    def setAddress(
        self,
        ip6Addr: typing.Tuple[
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
            int,
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhostaddress.html#setAddress-3

        **void QHostAddress::setAddress(const sockaddr * sockaddr )**

        This is an overloaded function.

        Sets the IPv4 or IPv6 address specified by the native structure
        **sockaddr**. Returns `true` and sets the address if the address was
        successfully parsed; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QAbstractItemModelReplica(QtCore.QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qabstractitemmodelreplica.html

    **Detailed Description**

    QAbstractItemModelReplica makes replicating QAbstractItemModels more
    efficient by employing caching and pre-fetching.

    **See also** **QAbstractItemModel** .
    """

    def setRootCacheSize(self, rootCacheSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#setRootCacheSize

        **void QAbstractItemModelReplica::setRootCacheSize(size_t rootCacheSize
        )**

        Sets the size of the internal cache to **rootCacheSize**.

        **See also** **rootCacheSize** ().
        """
        ...

    def rootCacheSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#rootCacheSize

        **size_t QAbstractItemModelReplica::rootCacheSize() const**

        Returns the current size of the internal cache. By default this is set
        to the value of the `QTRO_NODES_CACHE_SIZE` environment variable, or a
        default of `1000` if it is invalid or doesn't exist.

        **See also** **setRootCacheSize** ().
        """
        ...

    def hasData(self, index: QtCore.QModelIndex, role: int) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#hasData

        **bool QAbstractItemModelReplica::hasData(const QModelIndex & index ,
        int role ) const**

        Returns `true` if there exists **role** data for the item at **index**.
        Returns `false` in any other case.
        """
        ...

    def isInitialized(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#isInitialized

        **bool QAbstractItemModelReplica::isInitialized() const**

        Returns `true` if this replica has been initialized with data from the
        **Source**  object. Returns `false` otherwise.

        **See also** **initialized** ().
        """
        ...

    def roleNames(self) -> typing.Dict[int, QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#roleNames

        **[override virtual] QHash<int, QByteArray>
        QAbstractItemModelReplica::roleNames() const**

        Reimplements: **QAbstractItemModel::roleNames() const** .
        """
        ...

    def availableRoles(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#availableRoles

        **QList<int> QAbstractItemModelReplica::availableRoles() const**

        Returns a list of available roles.

        **See also** **QAbstractItemModel** .
        """
        ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#flags

        **[override virtual] Qt::ItemFlags
        QAbstractItemModelReplica::flags(const QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def headerData(
        self, section: int, orientation: QtCore.Qt.Orientation, role: int
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#headerData

        **[override virtual] QVariant QAbstractItemModelReplica::headerData(int
        section , Qt::Orientation orientation , int role ) const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        Returns the data for the given **role** and **section** in the header
        with the specified **orientation**.

        If the data is not available it will be requested from the **Source** .

        **See also** **QAbstractItemModel::headerData** ().
        """
        ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#columnCount

        **[override virtual] int QAbstractItemModelReplica::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#rowCount

        **[override virtual] int QAbstractItemModelReplica::rowCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#hasChildren

        **[override virtual] bool QAbstractItemModelReplica::hasChildren(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::hasChildren(const QModelIndex
        &parent) const** .
        """
        ...

    def index(
        self, row: int, column: int, parent: QtCore.QModelIndex = ...
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#index

        **[override virtual] QModelIndex QAbstractItemModelReplica::index(int
        row , int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#parent

        **[override virtual] QModelIndex QAbstractItemModelReplica::parent(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def setData(
        self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#setData

        **[override virtual] bool QAbstractItemModelReplica::setData(const
        QModelIndex & index , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#data

        **[override virtual] QVariant QAbstractItemModelReplica::data(const
        QModelIndex & index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        Returns the **role** data for the item at **index** if available in
        cache. A default-constructed **QVariant**  is returned if the index is
        invalid, the role is not one of the available roles, the **Replica**  is
        uninitialized or the data was not available. If the data was not
        available in cache it will be requested from the **Source** .

        **See also** **QAbstractItemModel::data** (), **hasData** (),
        **setData** (), and **isInitialized** ().
        """
        ...

    def selectionModel(self) -> QtCore.QItemSelectionModel:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#selectionModel

        **QItemSelectionModel *QAbstractItemModelReplica::selectionModel()
        const**

        Returns a pointer to the **QItemSelectionModel**  for the current
        **QAbstractItemModelReplica** .
        """
        ...

    @property
    def initialized(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractitemmodelreplica.html#initialized

        **[signal] void QAbstractItemModelReplica::initialized()**

        The initialized signal is emitted the first time we receive data from
        the **Source** .

        **See also** **isInitialized** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QDesignerWidgetBoxInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html

    **Detailed Description**

    QDesignerWidgetBoxInterface contains a collection of functions that is
    typically used to manipulate the contents of **Qt Designer** 's widget box.

    **Qt Designer** uses an XML file to populate its widget box. The name of
    that file is one of the widget box's properties, and you can retrieve it
    using the **fileName** () function.

    QDesignerWidgetBoxInterface also provides the **save** () function that
    saves the contents of the widget box in the file specified by the widget
    box's file name property. If you have made changes to the widget box, for
    example by dropping a widget into the widget box, without calling the
    **save** () function, the original content can be restored by a simple
    invocation of the **load** () function:

    **QDesignerWidgetBoxInterface**  *widgetBox = 0:
                widgetBox =
    formEditor->widgetBox();

                widgetBox->load();

    The QDesignerWidgetBoxInterface class is not intended to be instantiated
    directly. You can retrieve an interface to Qt Designer's widget box using
    the **QDesignerFormEditorInterface::widgetBox** () function. A pointer to
    **Qt Designer** 's current **QDesignerFormEditorInterface**  object
    (`formEditor` in the example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. When
    implementing a custom widget plugin, you must subclass the
    **QDesignerCustomWidgetInterface**  to expose your plugin to **Qt
    Designer**.

    If you want to save your changes, and at the same time preserve the original
    contents, you can use the **save** () function combined with the
    **setFileName** () function to save your changes into another file. Remember
    to store the name of the original file first:

    **QString**  originalFile = widgetBox->fileName();
    widgetBox->setFileName("myWidgetBox.xml");
                widgetBox->save();

    Then you can restore the original contents of the widget box by resetting
    the file name to the original file and calling **load** ():

    widgetBox->setFileName(originalFile);
                widgetBox->load();

    In a similar way, you can later use your customized XML file:

    if (widgetBox->filename() != "myWidgetBox.xml") {
    widgetBox->setFileName("myWidgetBox.xml");
    widgetBox->load();
                }

    **See also** **QDesignerFormEditorInterface** .
    """

    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html#QDesignerWidgetB
        oxInterface

        **QDesignerWidgetBoxInterface::QDesignerWidgetBoxInterface(QWidget *
        parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags())**

        Constructs a widget box interface with the given **parent** and the
        specified window **flags**.
        """
        ...

    def save(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html#save

        **[pure virtual] bool QDesignerWidgetBoxInterface::save()**

        Saves the contents of **Qt Designer** 's widget box in the file
        specified by the **fileName** () function. Returns true if the content
        is successfully saved; otherwise false.

        **See also** **fileName** () and **setFileName** ().
        """
        ...

    def load(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html#load

        **[pure virtual] bool QDesignerWidgetBoxInterface::load()**

        Populates **Qt Designer** 's widget box by loading (or reloading) the
        currently specified XML file. Returns true if the file is successfully
        loaded; otherwise false.

        **See also** **setFileName** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html#fileName

        **[pure virtual] QString QDesignerWidgetBoxInterface::fileName() const**

        Returns the name of the XML file **Qt Designer** is currently using to
        populate its widget box.

        **See also** **setFileName** ().
        """
        ...

    def setFileName(self, file_name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerwidgetboxinterface.html#setFileName

        **[pure virtual] void QDesignerWidgetBoxInterface::setFileName(const
        QString & fileName )**

        Sets the XML file that **Qt Designer** will use to populate its widget
        box, to **fileName**. You must call **load** () to update the widget box
        with the new XML file.

        **See also** **fileName** () and **load** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QFileSystemModel(QtCore.QAbstractItemModel):
    """
    https://doc.qt.io/qt-6/qfilesystemmodel.html

    **Detailed Description**

    This class provides access to the local filesystem, providing functions for
    renaming and removing files and directories, and for creating new
    directories. In the simplest case, it can be used with a suitable display
    widget as part of a browser or filter.

    QFileSystemModel can be accessed using the standard interface provided by
    **QAbstractItemModel** , but it also provides some convenience functions
    that are specific to a directory model. The **fileInfo** (), **isDir** (),
    **fileName** () and **filePath** () functions provide information about the
    underlying files and directories related to items in the model. Directories
    can be created and removed using **mkdir** (), **rmdir** ().

    **Note:** QFileSystemModel requires an instance of **QApplication** .

    **Example Usage**

    A directory model that displays the contents of a default directory is
    usually constructed with a parent object:

    **QFileSystemModel**  *model = new **QFileSystemModel** ;
    model->setRootPath(**QDir** ::currentPath());

    A tree view can be used to display the contents of the model

    **QTreeView**  *tree = new **QTreeView** (splitter);
    tree->setModel(model);

    and the contents of a particular directory can be displayed by setting the
    tree view's root index:

    tree->setRootIndex(model->index(**QDir** ::currentPath()));

    The view's root index can be used to control how much of a hierarchical
    model is displayed. QFileSystemModel provides a convenience function that
    returns a suitable model index for a path to a directory within the model.

    **Caching and Performance**

    QFileSystemModel will not fetch any files or directories until
    **setRootPath** () is called. This will prevent any unnecessary querying on
    the file system until that point such as listing the drives on Windows.

    QFileSystemModel uses a separate thread to populate itself so it will not
    cause the main thread to hang as the file system is being queried. Calls to
    **rowCount** () will return 0 until the model populates a directory.

    QFileSystemModel keeps a cache with file information. The cache is
    automatically kept up to date using the **QFileSystemWatcher** .

    **See also** **Model Classes** .
    """

    class Option(enum.Flag):
        DontWatchForChanges: QFileSystemModel = ...
        DontResolveSymlinks: QFileSystemModel = ...
        DontUseCustomDirectoryIcons: QFileSystemModel = ...

    class Roles(enum.IntEnum):
        FileIconRole: QFileSystemModel = ...
        FilePathRole: QFileSystemModel = ...
        FileNameRole: QFileSystemModel = ...
        FilePermissions: QFileSystemModel = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#QFileSystemModel

        **QFileSystemModel::QFileSystemModel(QObject * parent = nullptr)**

        Constructs a file system model with the given **parent**.
        """
        ...

    def roleNames(self) -> typing.Dict[int, QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#roleNames

        **[override virtual] QHash<int, QByteArray>
        QFileSystemModel::roleNames() const**

        Reimplements: **QAbstractItemModel::roleNames() const** .
        """
        ...

    def options(self) -> "QFileSystemModel.Option":
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#options-prop

        **[since 5.14] options : Options**

        This property holds the various options that affect the model

        By default, all options are disabled.

        Options should be set before changing properties.

        This property was introduced in Qt 5.14.

        **Access functions:**

        QFileSystemModel::Options **options** () const
        void **setOptions**
        (QFileSystemModel::Options **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def setOptions(self, options: "QFileSystemModel.Option") -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#options-prop

        **[since 5.14] options : Options**

        This property holds the various options that affect the model

        By default, all options are disabled.

        Options should be set before changing properties.

        This property was introduced in Qt 5.14.

        **Access functions:**

        QFileSystemModel::Options **options** () const
        void **setOptions**
        (QFileSystemModel::Options **options** )

        **See also** **setOption** () and **testOption** ().
        """
        ...

    def testOption(self, option: "QFileSystemModel.Option") -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#testOption

        **[since 5.14] bool
        QFileSystemModel::testOption(QFileSystemModel::Option option ) const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        This function was introduced in Qt 5.14.

        **See also** **options**  and **setOption** ().
        """
        ...

    def setOption(self, option: "QFileSystemModel.Option", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setOption

        **[since 5.14] void QFileSystemModel::setOption(QFileSystemModel::Option
        option , bool on = true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        Options should be set before changing properties.

        This function was introduced in Qt 5.14.

        **See also** **options**  and **testOption** ().
        """
        ...

    def sibling(
        self, row: int, column: int, idx: QtCore.QModelIndex
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#sibling

        **[override virtual] QModelIndex QFileSystemModel::sibling(int row , int
        column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractItemModel::sibling(int row, int column, const
        QModelIndex &index) const** .
        """
        ...

    def timerEvent(self, event: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#timerEvent

        **[override virtual protected] void
        QFileSystemModel::timerEvent(QTimerEvent * event )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#event

        **[override virtual protected] bool QFileSystemModel::event(QEvent *
        event )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def remove(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#remove

        **bool QFileSystemModel::remove(const QModelIndex & index )**

        Removes the model item **index** from the file system model and
        **deletes the corresponding file from the file system** , returning true
        if successful. If the item cannot be removed, false is returned.

        **Warning:** This function deletes files from the file system; it does
        **not** move them to a location where they can be recovered.

        **See also** **rmdir** ().
        """
        ...

    def fileInfo(self, aindex: QtCore.QModelIndex) -> QtCore.QFileInfo:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#fileInfo

        **QFileInfo QFileSystemModel::fileInfo(const QModelIndex & index )
        const**

        Returns the **QFileInfo**  for the item stored in the model under the
        given **index**.
        """
        ...

    def fileIcon(self, aindex: QtCore.QModelIndex) -> "QIcon":
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#fileIcon

        **QIcon QFileSystemModel::fileIcon(const QModelIndex & index ) const**

        Returns the icon for the item stored in the model under the given
        **index**.
        """
        ...

    def fileName(self, aindex: QtCore.QModelIndex) -> str:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#fileName

        **QString QFileSystemModel::fileName(const QModelIndex & index ) const**

        Returns the file name for the item stored in the model under the given
        **index**.
        """
        ...

    def rmdir(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#rmdir

        **bool QFileSystemModel::rmdir(const QModelIndex & index )**

        Removes the directory corresponding to the model item **index** in the
        file system model and **deletes the corresponding directory from the
        file system** , returning true if successful. If the directory cannot be
        removed, false is returned.

        **Warning:** This function deletes directories from the file system; it
        does **not** move them to a location where they can be recovered.

        **See also** **remove** ().
        """
        ...

    def permissions(self, index: QtCore.QModelIndex) -> QtCore.QFileDevice.Permission:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#permissions

        **QFile::Permissions QFileSystemModel::permissions(const QModelIndex &
        index ) const**

        Returns the complete OR-ed together combination of QFile::Permission for
        the **index**.
        """
        ...

    def mkdir(self, parent: QtCore.QModelIndex, name: str) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#mkdir

        **QModelIndex QFileSystemModel::mkdir(const QModelIndex & parent , const
        QString & name )**

        Create a directory with the **name** in the **parent** model index.
        """
        ...

    def lastModified(self, index: QtCore.QModelIndex) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#lastModified

        **QDateTime QFileSystemModel::lastModified(const QModelIndex & index )
        const**

        Returns the date and time when **index** was last modified.
        """
        ...

    def type(self, index: QtCore.QModelIndex) -> str:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#type

        **QString QFileSystemModel::type(const QModelIndex & index ) const**

        Returns the type of file **index** such as "Directory" or "JPEG file".
        """
        ...

    def size(self, index: QtCore.QModelIndex) -> int:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#size

        **qint64 QFileSystemModel::size(const QModelIndex & index ) const**

        Returns the size in bytes of **index**. If the file does not exist, 0 is
        returned.
        """
        ...

    def isDir(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#isDir

        **bool QFileSystemModel::isDir(const QModelIndex & index ) const**

        Returns `true` if the model item **index** represents a directory;
        otherwise returns `false`.
        """
        ...

    def filePath(self, index: QtCore.QModelIndex) -> str:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#filePath

        **QString QFileSystemModel::filePath(const QModelIndex & index ) const**

        Returns the path of the item stored in the model under the **index**
        given.
        """
        ...

    def nameFilters(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#nameFilters

        **QStringList QFileSystemModel::nameFilters() const**

        Returns a list of filters applied to the names in the model.

        **See also** **setNameFilters** ().
        """
        ...

    def setNameFilters(self, filters: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setNameFilters

        **void QFileSystemModel::setNameFilters(const QStringList & filters )**

        Sets the name **filters** to apply against the existing files.

        **See also** **nameFilters** ().
        """
        ...

    def nameFilterDisables(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#nameFilterDisables-prop

        **nameFilterDisables : bool**

        This property holds whether files that don't pass the name filter are
        hidden or disabled

        This property is `true` by default

        **Access functions:**

        bool **nameFilterDisables** () const
        void **setNameFilterDisables**
        (bool **enable** )
        """
        ...

    def setNameFilterDisables(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#nameFilterDisables-prop

        **nameFilterDisables : bool**

        This property holds whether files that don't pass the name filter are
        hidden or disabled

        This property is `true` by default

        **Access functions:**

        bool **nameFilterDisables** () const
        void **setNameFilterDisables**
        (bool **enable** )
        """
        ...

    def isReadOnly(self) -> bool:
        ...

    def setReadOnly(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#readOnly-prop

        **readOnly : bool**

        This property holds whether the directory model allows writing to the
        file system

        If this property is set to false, the directory model will allow
        renaming, copying and deleting of files and directories.

        This property is `true` by default

        **Access functions:**

        bool **isReadOnly** () const
        void **setReadOnly** (bool **enable** )
        """
        ...

    def resolveSymlinks(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#resolveSymlinks-prop

        **resolveSymlinks : bool**

        This property holds whether the directory model should resolve symbolic
        links

        This is only relevant on Windows.

        By default, this property is `true`.

        **Access functions:**

        bool **resolveSymlinks** () const
        void **setResolveSymlinks** (bool
        **enable** )

        **See also** **QFileSystemModel::Options** .

        **Member Function Documentation**
        """
        ...

    def setResolveSymlinks(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#resolveSymlinks-prop

        **resolveSymlinks : bool**

        This property holds whether the directory model should resolve symbolic
        links

        This is only relevant on Windows.

        By default, this property is `true`.

        **Access functions:**

        bool **resolveSymlinks** () const
        void **setResolveSymlinks** (bool
        **enable** )

        **See also** **QFileSystemModel::Options** .

        **Member Function Documentation**
        """
        ...

    def filter(self) -> QtCore.QDir.Filter:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#filter

        **QDir::Filters QFileSystemModel::filter() const**

        Returns the filter specified for the directory model.

        If a filter has not been set, the default filter is **QDir::AllEntries**
        | **QDir::NoDotAndDotDot**  | **QDir::AllDirs** .

        **See also** **setFilter** () and **QDir::Filters** .
        """
        ...

    def setFilter(self, filters: QtCore.QDir.Filter) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setFilter

        **void QFileSystemModel::setFilter(QDir::Filters filters )**

        Sets the directory model's filter to that specified by **filters**.

        Note that the filter you set should always include the **QDir::AllDirs**
        enum value, otherwise **QFileSystemModel**  won't be able to read the
        directory structure.

        **See also** **filter** () and **QDir::Filters** .
        """
        ...

    def iconProvider(self) -> QAbstractFileIconProvider:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#iconProvider

        **QAbstractFileIconProvider *QFileSystemModel::iconProvider() const**

        Returns the file icon provider for this directory model.

        **See also** **setIconProvider** ().
        """
        ...

    def setIconProvider(self, provider: QAbstractFileIconProvider) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setIconProvider

        **void QFileSystemModel::setIconProvider(QAbstractFileIconProvider *
        provider )**

        Sets the **provider** of file icons for the directory model.

        **See also** **iconProvider** ().
        """
        ...

    def rootDirectory(self) -> QtCore.QDir:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#rootDirectory

        **QDir QFileSystemModel::rootDirectory() const**

        The currently set directory

        **See also** **rootPath** ().
        """
        ...

    def rootPath(self) -> str:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#rootPath

        **QString QFileSystemModel::rootPath() const**

        The currently set root path

        **See also** **setRootPath** () and **rootDirectory** ().
        """
        ...

    def setRootPath(self, path: str) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setRootPath

        **QModelIndex QFileSystemModel::setRootPath(const QString & newPath )**

        Sets the directory that is being watched by the model to **newPath** by
        installing a **file system watcher**  on it. Any changes to files and
        directories within this directory will be reflected in the model.

        If the path is changed, the **rootPathChanged** () signal will be
        emitted.

        **Note:** This function does not change the structure of the model or
        modify the data available to views. In other words, the "root" of the
        model is **not** changed to include only files and directories within
        the directory specified by **newPath** in the file system.

        **See also** **rootPath** ().
        """
        ...

    def supportedDropActions(self) -> QtCore.Qt.DropAction:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#supportedDropActions

        **[override virtual] Qt::DropActions
        QFileSystemModel::supportedDropActions() const**

        Reimplements: **QAbstractItemModel::supportedDropActions() const** .
        """
        ...

    def dropMimeData(
        self,
        data: QtCore.QMimeData,
        action: QtCore.Qt.DropAction,
        row: int,
        column: int,
        parent: QtCore.QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#dropMimeData

        **[override virtual] bool QFileSystemModel::dropMimeData(const QMimeData
        * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractItemModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).

        Handles the **data** supplied by a drag and drop operation that ended
        with the given **action** over the row in the model specified by the
        **row** and **column** and by the **parent** index. Returns true if the
        operation was successful.

        **See also** **supportedDropActions** ().
        """
        ...

    def mimeData(
        self, indexes: typing.Iterable[QtCore.QModelIndex]
    ) -> QtCore.QMimeData:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#mimeData

        **[override virtual] QMimeData *QFileSystemModel::mimeData(const
        QModelIndexList & indexes ) const**

        Reimplements: **QAbstractItemModel::mimeData(const QModelIndexList
        &indexes) const** .

        Returns an object that contains a serialized description of the
        specified **indexes**. The format used to describe the items
        corresponding to the indexes is obtained from the **mimeTypes** ()
        function.

        If the list of indexes is empty, `nullptr` is returned rather than a
        serialized empty list.
        """
        ...

    def mimeTypes(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#mimeTypes

        **[override virtual] QStringList QFileSystemModel::mimeTypes() const**

        Reimplements: **QAbstractItemModel::mimeTypes() const** .

        Returns a list of MIME types that can be used to describe a list of
        items in the model.
        """
        ...

    def sort(self, column: int, order: QtCore.Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#sort

        **[override virtual] void QFileSystemModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractItemModel::sort** (int column, Qt::SortOrder
        order).
        """
        ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#flags

        **[override virtual] Qt::ItemFlags QFileSystemModel::flags(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::flags(const QModelIndex &index)
        const** .
        """
        ...

    def headerData(
        self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#headerData

        **[override virtual] QVariant QFileSystemModel::headerData(int section ,
        Qt::Orientation orientation , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .
        """
        ...

    def setData(
        self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#setData

        **[override virtual] bool QFileSystemModel::setData(const QModelIndex &
        idx , const QVariant & value , int role = Qt::EditRole)**

        Reimplements: **QAbstractItemModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        **See also** **data** ().
        """
        ...

    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#data

        **[override virtual] QVariant QFileSystemModel::data(const QModelIndex &
        index , int role = Qt::DisplayRole) const**

        Reimplements: **QAbstractItemModel::data(const QModelIndex &index, int
        role) const** .

        **See also** **setData** ().
        """
        ...

    def myComputer(self, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#myComputer

        **QVariant QFileSystemModel::myComputer(int role = Qt::DisplayRole)
        const**

        Returns the data stored under the given **role** for the item "My
        Computer".

        **See also** **Qt::ItemDataRole** .
        """
        ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#columnCount

        **[override virtual] int QFileSystemModel::columnCount(const QModelIndex
        & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#rowCount

        **[override virtual] int QFileSystemModel::rowCount(const QModelIndex &
        parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def fetchMore(self, parent: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#fetchMore

        **[override virtual] void QFileSystemModel::fetchMore(const QModelIndex
        & parent )**

        Reimplements: **QAbstractItemModel::fetchMore** (const QModelIndex
        &parent).
        """
        ...

    def canFetchMore(self, parent: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#canFetchMore

        **[override virtual] bool QFileSystemModel::canFetchMore(const
        QModelIndex & parent ) const**

        Reimplements: **QAbstractItemModel::canFetchMore(const QModelIndex
        &parent) const** .
        """
        ...

    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#hasChildren

        **[override virtual] bool QFileSystemModel::hasChildren(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::hasChildren(const QModelIndex
        &parent) const** .
        """
        ...

    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#parent

        **[override virtual] QModelIndex QFileSystemModel::parent(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    @typing.overload
    def index(
        self, row: int, column: int, parent: QtCore.QModelIndex = ...
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#index

        **[override virtual] QModelIndex QFileSystemModel::index(int row , int
        column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    @typing.overload
    def index(self, path: str, column: int = ...) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#index-1

        **QModelIndex QFileSystemModel::index(const QString & path , int column
        = 0) const**

        This is an overloaded function.

        Returns the model item index for the given **path** and **column**.
        """
        ...

    @property
    def directoryLoaded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#directoryLoaded

        **[signal] void QFileSystemModel::directoryLoaded(const QString & path
        )**

        This signal is emitted when the gatherer thread has finished to load the
        **path**.
        """
        ...

    @property
    def fileRenamed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#fileRenamed

        **[signal] void QFileSystemModel::fileRenamed(const QString & path ,
        const QString & oldName , const QString & newName )**

        This signal is emitted whenever a file with the **oldName** is
        successfully renamed to **newName**. The file is located in in the
        directory **path**.
        """
        ...

    @property
    def rootPathChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfilesystemmodel.html#rootPathChanged

        **[signal] void QFileSystemModel::rootPathChanged(const QString &
        newPath )**

        This signal is emitted whenever the root path has been changed to a
        **newPath**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGBasicGeometryNode(QSGNode):
    """
    https://doc.qt.io/qt-6/qsgbasicgeometrynode.html

    **Detailed Description**

    The QSGBasicGeometryNode class should not be used by itself. It is only
    encapsulates shared functionality between the **QSGGeometryNode**  and
    **QSGClipNode**  classes.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def geometry(self) -> QSGGeometry:
        """
        https://doc.qt.io/qt-6/qsgbasicgeometrynode.html#geometry

        **const QSGGeometry *QSGBasicGeometryNode::geometry() const**

        Returns this node's geometry.

        The geometry is null by default.

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, geometry: QSGGeometry) -> None:
        """
        https://doc.qt.io/qt-6/qsgbasicgeometrynode.html#setGeometry

        **void QSGBasicGeometryNode::setGeometry(QSGGeometry * geometry )**

        Sets the geometry of this node to **geometry**.

        If the node has the flag **QSGNode::OwnsGeometry**  set, it will also
        delete the geometry object it is pointing to. This flag is not set by
        default.

        If the geometry is changed without calling setGeometry() again, the user
        must also mark the geometry as dirty using **QSGNode::markDirty** ().

        **See also** **geometry** () and **markDirty** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtMultimedia
from PyQt6 import QtCore
from PyQt6.QtMultimediaWidgets import *


class QGraphicsVideoItem(QtWidgets.QGraphicsObject):
    """
    https://doc.qt.io/qt-6/qgraphicsvideoitem.html

    **Detailed Description**

    Attaching a QGraphicsVideoItem to a **QMediaPlayer**  or **QCamera**  allows
    it to display the video or image output of that media object.

    player = new **QMediaPlayer** (this);

        **QGraphicsVideoItem**  *item
    = new **QGraphicsVideoItem** ;
        player->setVideoOutput(item);
    graphicsView->scene()->addItem(item);
        graphicsView->show();
    player->setSource(**QUrl** ("http://example.com/myclip4.ogv"));
    player->play();

    **Note** : Only a single display output can be attached to a media object at
    one time.

    **See also** **QMediaPlayer** , **QVideoWidget** , and **QCamera** .
    """

    def __init__(self, parent: typing.Optional[QtWidgets.QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#QGraphicsVideoItem

        **QGraphicsVideoItem::QGraphicsVideoItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a graphics item that displays video.

        The **parent** is passed to **QGraphicsItem** .
        """
        ...

    def itemChange(
        self, change: QtWidgets.QGraphicsItem.GraphicsItemChange, value: typing.Any
    ) -> typing.Any:
        ...

    def timerEvent(self, event: QtCore.QTimerEvent) -> None:
        ...

    def type(self) -> int:
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: QtWidgets.QStyleOptionGraphicsItem,
        widget: typing.Optional[QtWidgets.QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#paint

        **[override virtual] void QGraphicsVideoItem::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#boundingRect

        **[override virtual] QRectF QGraphicsVideoItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def nativeSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#nativeSize-prop

        **[read-only] nativeSize : const QSizeF**

        This property holds the native size of the video.

        **Access functions:**

        QSizeF **nativeSize** () const

        **Notifier signal:**

        void ****nativeSizeChanged** ** (const QSizeF & **size** )
        """
        ...

    def setSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#size-prop

        **size : QSizeF**

        This property holds the video item's size.

        **QGraphicsVideoItem**  will draw video scaled to fit size according to
        its fillMode.

        **Access functions:**

        QSizeF **size** () const
        void **setSize** (const QSizeF & **size** )
        """
        ...

    def size(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#size-prop

        **size : QSizeF**

        This property holds the video item's size.

        **QGraphicsVideoItem**  will draw video scaled to fit size according to
        its fillMode.

        **Access functions:**

        QSizeF **size** () const
        void **setSize** (const QSizeF & **size** )
        """
        ...

    def setOffset(self, offset: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#offset-prop

        **offset : QPointF**

        This property holds the video item's offset.

        **QGraphicsVideoItem**  will draw video using the offset for its top
        left corner.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **offset** )
        """
        ...

    def offset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#offset-prop

        **offset : QPointF**

        This property holds the video item's offset.

        **QGraphicsVideoItem**  will draw video using the offset for its top
        left corner.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **offset** )
        """
        ...

    def setAspectRatioMode(self, mode: QtCore.Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#aspectRatioMode-prop

        **aspectRatioMode : Qt::AspectRatioMode**

        how a video is scaled to fit the graphics item's size.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )
        """
        ...

    def aspectRatioMode(self) -> QtCore.Qt.AspectRatioMode:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#aspectRatioMode-prop

        **aspectRatioMode : Qt::AspectRatioMode**

        how a video is scaled to fit the graphics item's size.

        **Access functions:**

        Qt::AspectRatioMode **aspectRatioMode** () const
        void
        **setAspectRatioMode** (Qt::AspectRatioMode **mode** )
        """
        ...

    def videoSink(self) -> QtMultimedia.QVideoSink:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#videoSink-prop

        **[read-only] videoSink : QVideoSink* const**

        Returns the underlying video sink that can render video frames to the
        current item. This property is never `nullptr`. Example of how to render
        video frames to **QGraphicsVideoItem** :

        **QGraphicsVideoItem**  *item = new **QGraphicsVideoItem** ;
        graphicsView->scene()->addItem(item);
            graphicsView->show();
        **QImage**  img = **QImage** ("images/qt-
        logo.png").convertToFormat(**QImage** ::Format_ARGB32);
        item->videoSink()->setVideoFrame(**QVideoFrame** (img));

        **Access functions:**

        QVideoSink * **videoSink** () const[see note below]

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QMediaPlayer::setVideoOutput** .

        **Member Function Documentation**
        """
        ...

    @property
    def nativeSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsvideoitem.html#nativeSizeChanged

        **[signal] void QGraphicsVideoItem::nativeSizeChanged(const QSizeF &
        size )**

        Signals that the native **size** of the video has changed.

        **Note:** Notifier signal for property **nativeSize** .
        """
        ...
